Minotaor
========

Minotaor is an amino acid sequence annotator for quickly identifying common protein tags
and linkers in an ORF. Additionally, it can flag peptide sequences or patterns that are
known to cause problems during translation.


**Install:**

.. code:: bash

  pip install minotaor


**Web documentation:** `<https://edinburgh-genome-foundry.github.io/Minotaor/>`_


**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/Minotaor/>`_


**License:** MIT

Copyright 2021, 2025 Edinburgh Genome Foundry, University of Edinburgh

----

More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Minotaor is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_
engineering biology software suite for DNA design, manufacturing and validation.
